@@ -5,7 +5,7 @@ from os.path import basename
 
 from integration_tests.test_cfngin.test_cfngin import Cfngin
 
-FILE_BASENAME = '.'.join(basename(__file__).split('.')[:-1])
+FILE_BASENAME = ".".join(basename(__file__).split(".")[:-1])
 
 
 class TestRawTemplate(Cfngin):
@@ -15,37 +15,35 @@ class TestRawTemplate(Cfngin):
 
     """
 
-    REQUIRED_FIXTURE_FILES = [FILE_BASENAME + '.yaml']
+    REQUIRED_FIXTURE_FILES = [FILE_BASENAME + ".yaml"]
     TEST_NAME = __name__
 
     def _build(self):
         """Execute and assert initial build."""
-        code, _stdout, stderr = self.runway_cmd('deploy')
-        assert code == 0, 'exit code should be zero'
+        code, _stdout, stderr = self.runway_cmd("deploy")
+        assert code == 0, "exit code should be zero"
         expected_lines = [
-            'raw-template-vpc:submitted (creating new stack)',
-            'raw-template-vpc:complete (creating new stack)'
+            "raw-template-vpc:submitted (creating new stack)",
+            "raw-template-vpc:complete (creating new stack)",
         ]
         for line in expected_lines:
             assert line in stderr, f'"{line}" missing from output'
 
     def _update_no_change(self):
         """Execute and assert second build with no changes."""
-        code, _stdout, stderr = self.runway_cmd('deploy')
-        assert code == 0, 'exit code should be zero'
-        expected_lines = [
-            'raw-template-vpc:skipped (nochange)'
-        ]
+        code, _stdout, stderr = self.runway_cmd("deploy")
+        assert code == 0, "exit code should be zero"
+        expected_lines = ["raw-template-vpc:skipped (nochange)"]
         for line in expected_lines:
             assert line in stderr, f'"{line}" missing from output'
 
     def _destroy(self):
         """Execute and assert destroy."""
-        code, _stdout, stderr = self.runway_cmd('destroy')
-        assert code == 0, 'exit code should be zero'
+        code, _stdout, stderr = self.runway_cmd("destroy")
+        assert code == 0, "exit code should be zero"
         expected_lines = [
-            'raw-template-vpc:submitted (submitted for destruction)',
-            'raw-template-vpc:complete (stack destroyed)'
+            "raw-template-vpc:submitted (submitted for destruction)",
+            "raw-template-vpc:complete (stack destroyed)",
         ]
         for line in expected_lines:
             assert line in stderr, f'"{line}" missing from output'
@@ -59,5 +57,5 @@ class TestRawTemplate(Cfngin):
 
     def teardown(self):
         """Teardown any created resources and delete files."""
-        self.runway_cmd('destroy')  # cleanup incase of failure
+        self.runway_cmd("destroy")  # cleanup incase of failure
         self.cleanup_fixtures()
