@@ -15,15 +15,15 @@ class TestDeploy(ModuleTags):
     def run(self):
         """Run tests."""
         self.init()
-        assert self.runway_cmd('deploy', ['app1']) == 0
-        self.check_stacks(['1'])
-        assert self.runway_cmd('deploy', ['app2']) == 0
-        self.check_stacks(['1', '2'])
-        self.runway_cmd('destroy', [])
-        assert self.runway_cmd('deploy', ['group-1-4']) == 0
-        self.check_stacks(['1', '4'])
+        assert self.runway_cmd("deploy", ["app1"]) == 0
+        self.check_stacks(["1"])
+        assert self.runway_cmd("deploy", ["app2"]) == 0
+        self.check_stacks(["1", "2"])
+        self.runway_cmd("destroy", [])
+        assert self.runway_cmd("deploy", ["group-1-4"]) == 0
+        self.check_stacks(["1", "4"])
 
     def teardown(self):
         """Teardown any created resources."""
-        self.runway_cmd('destroy', [])
+        self.runway_cmd("destroy", [])
         self.clean()
