@@ -9,12 +9,12 @@ import click
 from ...util import SafeHaven
 from .. import options
 
-LOGGER = logging.getLogger(__name__.replace('._', '.'))
+LOGGER = logging.getLogger(__name__.replace("._", "."))
 
-DOCS_URL = 'https://docs.onica.com/projects/runway/'
+DOCS_URL = "https://docs.onica.com/projects/runway/"
 
 
-@click.command('docs', short_help='open doc site')
+@click.command("docs", short_help="open doc site")
 @options.debug
 @options.no_color
 @options.verbose
@@ -25,15 +25,15 @@ def docs(**_):
         # Pyinstaller sets this var on systems to force using the internal lib
         # but, this can break some functionally around opening a web browser
         # using click so, reset/remove the var.
-        lp_key = 'LD_LIBRARY_PATH'  # for GNU/Linux and *BSD.
-        lp_orig = os.getenv(lp_key + '_ORIG')
+        lp_key = "LD_LIBRARY_PATH"  # for GNU/Linux and *BSD.
+        lp_orig = os.getenv(lp_key + "_ORIG")
         if lp_orig:
-            LOGGER.debug('temporarily reverting environ: %s=%s', lp_key, lp_orig)
+            LOGGER.debug("temporarily reverting environ: %s=%s", lp_key, lp_orig)
             os.environ[lp_key] = lp_orig  # restore the original, unmodified value
         else:
             # This happens when LD_LIBRARY_PATH was not set.
             # Remove the env var as a last resort:
-            LOGGER.debug('temporarily removing environ: %s', lp_key)
+            LOGGER.debug("temporarily removing environ: %s", lp_key)
             os.environ.pop(lp_key, None)
-        LOGGER.verbose('launching url: %s', DOCS_URL)
+        LOGGER.verbose("launching url: %s", DOCS_URL)
         click.launch(DOCS_URL)
