@@ -1,6 +1,7 @@
 """``runway gen-sample static-angular`` command."""
 import logging
 import sys
+from typing import Any  # pylint: disable=W
 
 import click
 
@@ -12,23 +13,22 @@ if sys.version_info.major > 2:
 else:
     from pathlib2 import Path  # pylint: disable=E
 
-LOGGER = logging.getLogger(__name__.replace('._', '.'))
+LOGGER = logging.getLogger(__name__.replace("._", "."))
 
 
-@click.command('static-angular',
-               short_help='angular static site (static-angular)')
+@click.command("static-angular", short_help="angular static site (static-angular)")
 @options.debug
 @options.no_color
 @options.verbose
 @click.pass_context
 def static_angular(ctx, **_):
-    # type: (click.Context) -> None
+    # type: (click.Context, Any) -> None
     """Generate a sample static site project using Angular."""
-    src = TEMPLATES / 'static-angular'
-    dest = Path.cwd() / 'static-angular'
+    src = TEMPLATES / "static-angular"
+    dest = Path.cwd() / "static-angular"
 
     copy_sample(ctx, src, dest)
-    convert_gitignore(dest / 'sampleapp.web/_gitignore')
+    convert_gitignore(dest / "sampleapp.web/_gitignore")
 
     LOGGER.success("Sample static Angular site repo created at %s", dest)
-    LOGGER.notice('See the README for setup and deployment instructions.')
+    LOGGER.notice("See the README for setup and deployment instructions.")
