@@ -8,12 +8,12 @@ from ... import options
 from ._install import install
 from ._run import run
 
-__all__ = ['install', 'run']
+__all__ = ["install", "run"]
 
 COMMANDS = [install, run]
 
 
-@click.group('tfenv', short_help='terraform (install|run)')
+@click.group("tfenv", short_help="terraform (install|run)")
 @options.debug
 @options.no_color
 @options.verbose
