@@ -35,7 +35,7 @@ DESTROYING_STATUS = SubmittedStatus("submitted for destruction")
 
 def build_stack_tags(stack):
     """Build a common set of tags to attach to a stack."""
-    return [{'Key': t[0], 'Value': t[1]} for t in stack.tags.items()]
+    return [{"Key": t[0], "Value": t[1]} for t in stack.tags.items()]
 
 
 def should_update(stack):
@@ -50,11 +50,11 @@ def should_update(stack):
     """
     if stack.locked:
         if not stack.force:
-            LOGGER.debug("%s:locked and not in --force list; "
-                         "refusing to update", stack.name)
+            LOGGER.debug(
+                "%s:locked and not in --force list; refusing to update", stack.name
+            )
             return False
-        LOGGER.debug("%s:locked but is in --force "
-                     "list", stack.name)
+        LOGGER.debug("%s:locked but is in --force list", stack.name)
     return True
 
 
@@ -112,17 +112,17 @@ def _resolve_parameters(parameters, blueprint):
 
     for key, value in parameters.items():
         if key not in param_defs:
-            LOGGER.debug("blueprint %s does not use parameter %s",
-                         blueprint.name, key)
+            LOGGER.debug("blueprint %s does not use parameter %s", blueprint.name, key)
             continue
         if value is None:
-            LOGGER.debug("got NoneType value for parameter %s; not submitting it "
-                         "to cloudformation, default value should be used",
-                         key)
+            LOGGER.debug(
+                "got NoneType value for parameter %s; not submitting it "
+                "to cloudformation, default value should be used",
+                key,
+            )
             continue
         if isinstance(value, bool):
-            LOGGER.debug("converting parameter %s boolean \"%s\" to string",
-                         key, value)
+            LOGGER.debug('converting parameter %s boolean "%s" to string', key, value)
             value = str(value).lower()
         params[key] = value
     return params
@@ -132,8 +132,9 @@ class UsePreviousParameterValue(object):  # pylint: disable=too-few-public-metho
     """Class used to indicate a Parameter should use it's existing value."""
 
 
-def _handle_missing_parameters(parameter_values, all_params, required_params,
-                               existing_stack=None):
+def _handle_missing_parameters(
+    parameter_values, all_params, required_params, existing_stack=None
+):
     """Handle any missing parameters.
 
     If an existing_stack is provided, look up missing parameters there.
@@ -158,16 +159,14 @@ def _handle_missing_parameters(parameter_values, all_params, required_params,
 
     """
     missing_params = list(set(all_params) - set(parameter_values.keys()))
-    if existing_stack and 'Parameters' in existing_stack:
+    if existing_stack and "Parameters" in existing_stack:
         stack_parameters = [
             param["ParameterKey"] for param in existing_stack["Parameters"]
         ]
         for param in missing_params:
             if param in stack_parameters:
                 LOGGER.debug(
-                    "using previous value for parameter %s from existing "
-                    "stack",
-                    param
+                    "using previous value for parameter %s from existing stack", param,
                 )
                 parameter_values[param] = UsePreviousParameterValue
     final_missing = list(set(required_params) - set(parameter_values.keys()))
@@ -192,12 +191,7 @@ def handle_hooks(stage, hooks, provider, context, dump, outline):
 
     """
     if not outline and not dump and hooks:
-        utils.handle_hooks(
-            stage=stage,
-            hooks=hooks,
-            provider=provider,
-            context=context
-        )
+        utils.handle_hooks(stage=stage, hooks=hooks, provider=provider, context=context)
 
 
 class Action(BaseAction):
@@ -215,8 +209,8 @@ class Action(BaseAction):
 
     """
 
-    DESCRIPTION = 'Create/Update stacks'
-    NAME = 'build'
+    DESCRIPTION = "Create/Update stacks"
+    NAME = "build"
 
     @staticmethod
     def build_parameters(stack, provider_stack=None):
@@ -233,9 +227,9 @@ class Action(BaseAction):
         resolved = _resolve_parameters(stack.parameter_values, stack.blueprint)
         required_parameters = list(stack.required_parameter_definitions)
         all_parameters = list(stack.all_parameter_definitions)
-        parameters = _handle_missing_parameters(resolved, all_parameters,
-                                                required_parameters,
-                                                provider_stack)
+        parameters = _handle_missing_parameters(
+            resolved, all_parameters, required_parameters, provider_stack
+        )
 
         param_list = []
 
@@ -250,7 +244,9 @@ class Action(BaseAction):
 
         return param_list
 
-    def _destroy_stack(self, stack, **kwargs):  # pylint: disable=too-many-return-statements
+    def _destroy_stack(  # pylint: disable=too-many-return-statements
+        self, stack, **kwargs
+    ):
         """Delete a CloudFormation stack.
 
         Used to remove stacks that exist in the persistent graph but not
@@ -275,9 +271,11 @@ class Action(BaseAction):
                 return DESTROYED_STATUS
             return StackDoesNotExistStatus()
 
-        LOGGER.debug("%s:provider status: %s",
-                     provider.get_stack_name(stack_data),
-                     provider.get_stack_status(stack_data))
+        LOGGER.debug(
+            "%s:provider status: %s",
+            provider.get_stack_name(stack_data),
+            provider.get_stack_status(stack_data),
+        )
         try:
             if provider.is_stack_being_destroyed(stack_data):
                 return DESTROYING_STATUS
@@ -287,7 +285,7 @@ class Action(BaseAction):
             if wait and provider.is_stack_in_progress(stack_data):
                 return WAITING
             LOGGER.debug("%s:destroying stack", stack.fqn)
-            provider.destroy_stack(stack_data, action='build')
+            provider.destroy_stack(stack_data, action="build")
             return DESTROYING_STATUS
         except CancelExecution:
             return SkippedStatus(reason="canceled execution")
@@ -319,8 +317,7 @@ class Action(BaseAction):
             provider_stack = None
 
         if provider_stack and not should_update(stack):
-            stack.set_outputs(
-                self.provider.get_output_dict(provider_stack))
+            stack.set_outputs(self.provider.get_output_dict(provider_stack))
             return NotUpdatedStatus()
 
         recreate = False
@@ -331,15 +328,17 @@ class Action(BaseAction):
                 provider.get_stack_status(provider_stack),
             )
 
-            if provider.is_stack_rolling_back(provider_stack):  # pylint: disable=no-else-return
-                if 'rolling back' in old_status.reason:
+            if provider.is_stack_rolling_back(  # pylint: disable=no-else-return
+                provider_stack
+            ):
+                if "rolling back" in old_status.reason:
                     return old_status
 
                 LOGGER.debug("%s:entered roll back", stack.fqn)
-                if 'updating' in old_status.reason:
-                    reason = 'rolling back update'
+                if "updating" in old_status.reason:
+                    reason = "rolling back update"
                 else:
-                    reason = 'rolling back new stack'
+                    reason = "rolling back new stack"
 
                 return SubmittedStatus(reason)
             elif provider.is_stack_in_progress(provider_stack):
@@ -354,16 +353,14 @@ class Action(BaseAction):
             # a successful update.
             elif provider.is_stack_failed(provider_stack):
                 reason = old_status.reason
-                if 'rolling' in reason:
-                    reason = reason.replace('rolling', 'rolled')
+                if "rolling" in reason:
+                    reason = reason.replace("rolling", "rolled")
                 status_reason = provider.get_rollback_status_reason(stack.fqn)
-                LOGGER.info(
-                    "%s:roll back reason: %s", stack.fqn, status_reason)
+                LOGGER.info("%s:roll back reason: %s", stack.fqn, status_reason)
                 return FailedStatus(reason)
 
             elif provider.is_stack_completed(provider_stack):
-                stack.set_outputs(
-                    provider.get_output_dict(provider_stack))
+                stack.set_outputs(provider.get_output_dict(provider_stack))
                 return CompleteStatus(old_status.reason)
             else:
                 return old_status
@@ -380,16 +377,26 @@ class Action(BaseAction):
 
         if recreate:
             LOGGER.debug("%s:re-creating stack", stack.fqn)
-            provider.create_stack(stack.fqn, template, parameters,
-                                  tags, stack_policy=stack_policy,
-                                  termination_protection=stack.termination_protection)
+            provider.create_stack(
+                stack.fqn,
+                template,
+                parameters,
+                tags,
+                stack_policy=stack_policy,
+                termination_protection=stack.termination_protection,
+            )
             return SubmittedStatus("re-creating stack")
         if not provider_stack:
             LOGGER.debug("%s:creating new stack", stack.fqn)
-            provider.create_stack(stack.fqn, template, parameters, tags,
-                                  force_change_set,
-                                  stack_policy=stack_policy,
-                                  termination_protection=stack.termination_protection)
+            provider.create_stack(
+                stack.fqn,
+                template,
+                parameters,
+                tags,
+                force_change_set,
+                stack_policy=stack_policy,
+                termination_protection=stack.termination_protection,
+            )
             return SubmittedStatus("creating new stack")
 
         try:
@@ -397,7 +404,7 @@ class Action(BaseAction):
             if wait and provider.is_stack_in_progress(provider_stack):
                 return WAITING
             if provider.prepare_stack_for_update(provider_stack, tags):
-                existing_params = provider_stack.get('Parameters', [])
+                existing_params = provider_stack.get("Parameters", [])
                 provider.update_stack(
                     stack.fqn,
                     template,
@@ -407,7 +414,7 @@ class Action(BaseAction):
                     force_interactive=stack.protected,
                     force_change_set=force_change_set,
                     stack_policy=stack_policy,
-                    termination_protection=stack.termination_protection
+                    termination_protection=stack.termination_protection,
                 )
 
                 LOGGER.debug("%s:updating existing stack", stack.fqn)
@@ -470,8 +477,7 @@ class Action(BaseAction):
             return self._generate_plan(tail)
 
         graph = Graph()
-        config_stack_names = [stack.name for stack in
-                              self.context.get_stacks()]
+        config_stack_names = [stack.name for stack in self.context.get_stacks()]
         inverse_steps = []
         persist_graph = self.context.persistent_graph.transposed()
 
@@ -482,11 +488,13 @@ class Action(BaseAction):
         for ind_node, dep_nodes in persist_graph.dag.graph.items():
             if ind_node not in config_stack_names:
                 inverse_steps.append(
-                    Step.from_stack_name(ind_node, self.context,
-                                         requires=list(dep_nodes),
-                                         fn=self._destroy_stack,
-                                         watch_func=(self._tail_stack if
-                                                     tail else None))
+                    Step.from_stack_name(
+                        ind_node,
+                        self.context,
+                        requires=list(dep_nodes),
+                        fn=self._destroy_stack,
+                        watch_func=(self._tail_stack if tail else None),
+                    )
                 )
 
         graph.add_steps(inverse_steps)
@@ -494,36 +502,29 @@ class Action(BaseAction):
         # invert what is going to be destroyed to retain dependencies
         graph = graph.transposed()
 
-        steps = [Step(stack, fn=self._launch_stack,
-                      watch_func=(self._tail_stack if tail else None))
-                 for stack in self.context.get_stacks()]
+        steps = [
+            Step(
+                stack,
+                fn=self._launch_stack,
+                watch_func=(self._tail_stack if tail else None),
+            )
+            for stack in self.context.get_stacks()
+        ]
 
-        steps += [Step(target, fn=target_fn)
-                  for target in self.context.get_targets()]
+        steps += [Step(target, fn=target_fn) for target in self.context.get_targets()]
 
         graph.add_steps(steps)
 
-        return Plan(
-            context=self.context,
-            description=self.DESCRIPTION,
-            graph=graph
-        )
+        return Plan(context=self.context, description=self.DESCRIPTION, graph=graph)
 
     def pre_run(self, **kwargs):
         """Any steps that need to be taken prior to running the action."""
-        dump = kwargs.get('dump', False)
-        outline = kwargs.get('outline', False)
+        dump = kwargs.get("dump", False)
+        outline = kwargs.get("outline", False)
         if should_ensure_cfn_bucket(outline, dump):
             self.ensure_cfn_bucket()
         hooks = self.context.config.pre_build
-        handle_hooks(
-            "pre_build",
-            hooks,
-            self.provider,
-            self.context,
-            dump,
-            outline
-        )
+        handle_hooks("pre_build", hooks, self.provider, self.context, dump, outline)
 
     def run(self, **kwargs):
         """Kicks off the build/update of the stacks in the stack_definitions.
@@ -531,16 +532,16 @@ class Action(BaseAction):
         This is the main entry point for the Builder.
 
         """
-        dump = kwargs.get('dump', False)
-        outline = kwargs.get('outline', False)
-        plan = self.__generate_plan(tail=kwargs.get('tail'))
+        dump = kwargs.get("dump", False)
+        outline = kwargs.get("outline", False)
+        plan = self.__generate_plan(tail=kwargs.get("tail"))
         if not plan.keys():
-            LOGGER.warning('no stacks detected (error in config?)')
+            LOGGER.warning("no stacks detected (error in config?)")
         if not outline and not dump:
             plan.outline(logging.DEBUG)
             self.context.lock_persistent_graph(plan.lock_code)
             LOGGER.debug("launching stacks: %s", ", ".join(plan.keys()))
-            walker = build_walker(kwargs.get('concurrency', 0))
+            walker = build_walker(kwargs.get("concurrency", 0))
             try:
                 plan.execute(walker)
             finally:
@@ -550,19 +551,11 @@ class Action(BaseAction):
             if outline:
                 plan.outline()
             if dump:
-                plan.dump(directory=dump, context=self.context,
-                          provider=self.provider)
+                plan.dump(directory=dump, context=self.context, provider=self.provider)
 
     def post_run(self, **kwargs):
         """Any steps that need to be taken after running the action."""
-        dump = kwargs.get('dump', False)
-        outline = kwargs.get('outline', False)
+        dump = kwargs.get("dump", False)
+        outline = kwargs.get("outline", False)
         hooks = self.context.config.post_build
-        handle_hooks(
-            "post_build",
-            hooks,
-            self.provider,
-            self.context,
-            dump,
-            outline
-        )
+        handle_hooks("post_build", hooks, self.provider, self.context, dump, outline)
