@@ -3,8 +3,4 @@ from ._deploy_environment import DeployEnvironment
 from ._deployment import Deployment
 from ._module import Module
 
-__all__ = [
-    'DeployEnvironment',
-    'Deployment',
-    'Module'
-]
+__all__ = ["DeployEnvironment", "Deployment", "Module"]
