@@ -16,10 +16,11 @@ if TYPE_CHECKING:
 LOGGER = logging.getLogger(__name__)
 
 
-def update(context,  # type: Context
-           provider,  # type: BaseProvider
-           **kwargs  # type: Optional[Dict[str, Any]]
-          ):  # noqa: E124
+def update(
+    context,  # type: Context
+    provider,  # type: BaseProvider
+    **kwargs  # type: Optional[Dict[str, Any]]
+):
     # type: (...) -> Union[Dict[str, Any], bool]
     """Retrieve/Update the domain name of the specified client.
 
@@ -39,46 +40,42 @@ def update(context,  # type: Context
 
     """
     session = context.get_session()
-    cognito_client = session.client('cognito-idp')
+    cognito_client = session.client("cognito-idp")
 
     context_dict = {}
 
-    user_pool_id = context.hook_data['aae_user_pool_id_retriever']['id']
-    client_id = kwargs['client_id']
-    user_pool = cognito_client.describe_user_pool(UserPoolId=user_pool_id).get('UserPool')
-    (user_pool_region, user_pool_hash) = user_pool_id.split('_')
+    user_pool_id = context.hook_data["aae_user_pool_id_retriever"]["id"]
+    client_id = kwargs["client_id"]
+    user_pool = cognito_client.describe_user_pool(UserPoolId=user_pool_id).get(
+        "UserPool"
+    )
+    (user_pool_region, user_pool_hash) = user_pool_id.split("_")
 
-    domain_prefix = user_pool.get('CustomDomain') or user_pool.get('Domain')
+    domain_prefix = user_pool.get("CustomDomain") or user_pool.get("Domain")
 
     # Return early if we already have a domain
     if domain_prefix:
-        context_dict['domain'] = get_user_pool_domain(
-            domain_prefix,
-            user_pool_region
-        )
+        context_dict["domain"] = get_user_pool_domain(domain_prefix, user_pool_region)
         return context_dict
 
     try:
-        domain_prefix = ('%s-%s' % (user_pool_hash, client_id)).lower()
+        domain_prefix = ("%s-%s" % (user_pool_hash, client_id)).lower()
 
         cognito_client.create_user_pool_domain(
-            Domain=domain_prefix,
-            UserPoolId=user_pool_id
-        )
-        context_dict['domain'] = get_user_pool_domain(
-            domain_prefix,
-            user_pool_region
+            Domain=domain_prefix, UserPoolId=user_pool_id
         )
+        context_dict["domain"] = get_user_pool_domain(domain_prefix, user_pool_region)
         return context_dict
     except Exception:  # pylint: disable=broad-except
-        LOGGER.exception('could not update user pool domain: %s', user_pool_id)
+        LOGGER.exception("could not update user pool domain: %s", user_pool_id)
         return False
 
 
-def delete(context,  # type: Context # pylint: disable=unused-import
-           provider,  # type: BaseProvider
-           **kwargs  # type: Optional[Dict[str, Any]]
-          ):  # noqa: E124
+def delete(
+    context,  # type: Context
+    provider,  # type: BaseProvider
+    **kwargs  # type: Optional[Dict[str, Any]]
+):
     # type: (...) -> Union[Dict[str, Any], bool]
     """Delete the domain if the user pool was created by Runway.
 
@@ -98,26 +95,23 @@ def delete(context,  # type: Context # pylint: disable=unused-import
 
     """
     session = context.get_session()
-    cognito_client = session.client('cognito-idp')
+    cognito_client = session.client("cognito-idp")
 
-    user_pool_id = context.hook_data['aae_user_pool_id_retriever']['id']
-    client_id = kwargs['client_id']
-    (_, user_pool_hash) = user_pool_id.split('_')
-    domain_prefix = ('%s-%s' % (user_pool_hash, client_id)).lower()
+    user_pool_id = context.hook_data["aae_user_pool_id_retriever"]["id"]
+    client_id = kwargs["client_id"]
+    (_, user_pool_hash) = user_pool_id.split("_")
+    domain_prefix = ("%s-%s" % (user_pool_hash, client_id)).lower()
 
     try:
         cognito_client.delete_user_pool_domain(
-            UserPoolId=user_pool_id,
-            Domain=domain_prefix
+            UserPoolId=user_pool_id, Domain=domain_prefix
         )
         return True
     except cognito_client.exceptions.InvalidParameterException:
-        LOGGER.info(
-            'skipped deletion; no domain with prefix "%s"', domain_prefix
-        )
+        LOGGER.info('skipped deletion; no domain with prefix "%s"', domain_prefix)
         return True
     except Exception:  # pylint: disable=broad-except
-        LOGGER.exception('could not delete user pool domain')
+        LOGGER.exception("could not delete user pool domain")
         return False
 
 
@@ -129,4 +123,4 @@ def get_user_pool_domain(prefix, region):
         region (str): The region in which the pool resides.
 
     """
-    return '%s.auth.%s.amazoncognito.com' % (prefix, region)
+    return "%s.auth.%s.amazoncognito.com" % (prefix, region)
