@@ -23,7 +23,7 @@ class Git(Source):
     """
 
     # Added for documentation purposes
-    def __init__(self, uri='', location='', options=None, **kwargs):
+    def __init__(self, uri="", location="", options=None, **kwargs):
         # type(Dict[str, Union[str, Dict[str, str]]]) -> Source
         """Git Path Source.
 
@@ -54,9 +54,9 @@ class Git(Source):
         from git import Repo  # pylint: disable=import-outside-toplevel
 
         ref = self.__determine_git_ref()  # type: str
-        dir_name = '_'.join([self.sanitize_git_path(self.uri), ref])  # type: str
+        dir_name = "_".join([self.sanitize_git_path(self.uri), ref])  # type: str
         cached_dir_path = os.path.join(self.cache_dir, dir_name)  # type: str
-        cached_path = ''  # type: str
+        cached_path = ""  # type: str
 
         if not os.path.isdir(cached_dir_path):
             tmp_dir = tempfile.mkdtemp()
@@ -82,45 +82,48 @@ class Git(Source):
             ref (str): The git reference value
 
         """
-        cmd = ['git', 'ls-remote', self.uri, ref]
-        LOGGER.debug('getting commit ID from repo: %s', ' '.join(cmd))
+        cmd = ["git", "ls-remote", self.uri, ref]
+        LOGGER.debug("getting commit ID from repo: %s", " ".join(cmd))
         lsremote_output = subprocess.check_output(cmd)
         # pylint: disable=unsupported-membership-test
         if b"\t" in lsremote_output:
             commit_id = lsremote_output.split(b"\t")[0]  # type List[str]
             LOGGER.debug("matching commit id found: %s", commit_id)
             return commit_id
-        raise ValueError("Ref \"%s\" not found for repo %s." % (ref, self.uri))
+        raise ValueError('Ref "%s" not found for repo %s.' % (ref, self.uri))
 
     def __determine_git_ls_remote_ref(self):
         # type: () -> str
         """Determine remote ref, defaulting to HEAD unless a branch is found."""
         ref = "HEAD"
 
-        if self.options.get('branch'):
-            ref = "refs/heads/%s" % self.options.get('branch')  # type: str
+        if self.options.get("branch"):
+            ref = "refs/heads/%s" % self.options.get("branch")  # type: str
 
         return ref
 
     def __determine_git_ref(self):
         # type: () -> str
         """Determine the git reference code."""
-        ref_config_keys = 0   # type: int
+        ref_config_keys = 0  # type: int
 
-        for i in ['commit', 'tag', 'branch']:
+        for i in ["commit", "tag", "branch"]:
             if self.options.get(i):
                 ref_config_keys += 1
         if ref_config_keys > 1:
-            raise ImportError("Fetching remote git sources failed: "
-                              "conflicting revisions (e.g. 'commit', 'tag', "
-                              "'branch') specified for a package source")
+            raise ImportError(
+                "Fetching remote git sources failed: conflicting revisions "
+                "(e.g. 'commit', 'tag', 'branch') specified for a package source"
+            )
 
-        if self.options.get('commit'):
-            ref = self.options.get('commit')  # type: str
-        elif self.options.get('tag'):
-            ref = self.options.get('tag')  # type: str
+        if self.options.get("commit"):
+            ref = self.options.get("commit")  # type: str
+        elif self.options.get("tag"):
+            ref = self.options.get("tag")  # type: str
         else:
-            ref = self.__git_ls_remote(self.__determine_git_ls_remote_ref())  # ty pe: str
+            ref = self.__git_ls_remote(
+                self.__determine_git_ls_remote_ref()
+            )  # ty pe: str
         if sys.version_info[0] > 2 and isinstance(ref, bytes):
             return ref.decode()
         return ref
@@ -135,10 +138,10 @@ class Git(Source):
 
         """
         dir_name = path  # type: str
-        split = path.split('//')  # type: List[str]
+        split = path.split("//")  # type: List[str]
         domain = split[len(split) - 1]  # type: str
 
-        if domain.endswith('.git'):
+        if domain.endswith(".git"):
             dir_name = domain[:-4]
 
         return cls.sanitize_directory_path(dir_name)
