@@ -17,6 +17,6 @@ class TestHandler(object):
         # type: (str) -> List[str]
         """Return list of directories."""
         repo_dirs = next(os.walk(provided_path))[1]
-        if '.git' in repo_dirs:
-            repo_dirs.remove('.git')  # not relevant for any repo operations
+        if ".git" in repo_dirs:
+            repo_dirs.remove(".git")  # not relevant for any repo operations
         return repo_dirs
