@@ -14,29 +14,38 @@ else:
 
 def test_run_aws_head_bucket(monkeypatch):
     """Test ``runway run-aws s3api head-bucket``."""
-    monkeypatch.setenv('AWS_ACCESS_KEY_ID', 'testing')
-    monkeypatch.setenv('AWS_SECRET_ACCESS_KEY', 'testing')
-    monkeypatch.setenv('DEBUG', '0')
+    monkeypatch.setenv("AWS_ACCESS_KEY_ID", "testing")
+    monkeypatch.setenv("AWS_SECRET_ACCESS_KEY", "testing")
+    monkeypatch.setenv("DEBUG", "0")
     runner = CliRunner()
-    result = runner.invoke(cli, ['run-aws', 's3api', 'head-bucket',
-                                 '--bucket', 'example-bucket',
-                                 '--region', 'us-east-1'])
+    result = runner.invoke(
+        cli,
+        [
+            "run-aws",
+            "s3api",
+            "head-bucket",
+            "--bucket",
+            "example-bucket",
+            "--region",
+            "us-east-1",
+        ],
+    )
     assert result.exit_code != 0
     # exact error could differ
-    assert 'when calling the HeadBucket operation:' in result.output
+    assert "when calling the HeadBucket operation:" in result.output
 
 
 def test_run_aws_version():
     """Test ``runway run-aws --version``."""
     runner = CliRunner()
-    result = runner.invoke(cli, ['run-aws', '--version'])
+    result = runner.invoke(cli, ["run-aws", "--version"])
     assert result.exit_code == 0
-    assert version('awscli') in result.output
+    assert version("awscli") in result.output
 
 
 def test_run_aws_version_separator():
     """Test ``runway run-aws -- --version``."""
     runner = CliRunner()
-    result = runner.invoke(cli, ['run-aws', '--', '--version'])
+    result = runner.invoke(cli, ["run-aws", "--", "--version"])
     assert result.exit_code == 0
-    assert version('awscli') in result.output
+    assert version("awscli") in result.output
