@@ -20,24 +20,24 @@ def test_tfenv_install(cd_tmp_path, caplog):
     For best results, remove any existing installs.
 
     """
-    caplog.set_level(logging.DEBUG, logger='runway.cli.commands.tfenv')
-    (cd_tmp_path / '.terraform-version').write_text(six.u('0.12.0'))
+    caplog.set_level(logging.DEBUG, logger="runway.cli.commands.tfenv")
+    (cd_tmp_path / ".terraform-version").write_text(six.u("0.12.0"))
     runner = CliRunner()
-    result = runner.invoke(cli, ['tfenv', 'install'])
+    result = runner.invoke(cli, ["tfenv", "install"])
     assert result.exit_code == 0
 
-    tf_bin = Path(caplog.messages[-1].strip('terraform path: '))
+    tf_bin = Path(caplog.messages[-1].strip("terraform path: "))
     assert tf_bin.exists()
 
 
 def test_tfenv_install_no_version_file(cd_tmp_path, caplog):
     """Test ``runway tfenv install`` no version file."""
-    caplog.set_level(logging.ERROR, logger='runway')
+    caplog.set_level(logging.ERROR, logger="runway")
     runner = CliRunner()
-    result = runner.invoke(cli, ['tfenv', 'install'])
+    result = runner.invoke(cli, ["tfenv", "install"])
     assert result.exit_code == 1
 
-    assert 'unable to find a .terraform-version file' in '\n'.join(caplog.messages)
+    assert "unable to find a .terraform-version file" in "\n".join(caplog.messages)
 
 
 def test_tfenv_install_version(caplog):
@@ -46,23 +46,23 @@ def test_tfenv_install_version(caplog):
     For best results, remove any existing installs.
 
     """
-    caplog.set_level(logging.DEBUG, logger='runway.cli.commands.tfenv')
+    caplog.set_level(logging.DEBUG, logger="runway.cli.commands.tfenv")
     runner = CliRunner()
-    result = runner.invoke(cli, ['tfenv', 'install', '0.12.1'])
+    result = runner.invoke(cli, ["tfenv", "install", "0.12.1"])
     assert result.exit_code == 0
 
-    kb_bin = Path(caplog.messages[-1].strip('terraform path: '))
+    kb_bin = Path(caplog.messages[-1].strip("terraform path: "))
     assert kb_bin.exists()
 
 
 def test_tfenv_run_no_version_file(cd_tmp_path, caplog):
     """Test ``runway tfenv run -- --help`` no version file."""
-    caplog.set_level(logging.ERROR, logger='runway')
+    caplog.set_level(logging.ERROR, logger="runway")
     runner = CliRunner()
-    result = runner.invoke(cli, ['tfenv', 'run', '--', '--help'])
+    result = runner.invoke(cli, ["tfenv", "run", "--", "--help"])
     assert result.exit_code == 1
 
-    assert 'unable to find a .terraform-version file' in '\n'.join(caplog.messages)
+    assert "unable to find a .terraform-version file" in "\n".join(caplog.messages)
 
 
 def test_tfenv_run_separator(cd_tmp_path, capfd):
@@ -74,13 +74,13 @@ def test_tfenv_run_separator(cd_tmp_path, capfd):
     pass options shared with Runway such as ``--help``.
 
     """
-    (cd_tmp_path / '.terraform-version').write_text(six.u('0.12.0'))
+    (cd_tmp_path / ".terraform-version").write_text(six.u("0.12.0"))
     runner = CliRunner()
-    result = runner.invoke(cli, ['tfenv', 'run', '--', '--help'])
+    result = runner.invoke(cli, ["tfenv", "run", "--", "--help"])
     captured = capfd.readouterr()  # capfd required for subprocess
     assert result.exit_code == 0
-    assert 'runway' not in captured.out
-    assert 'terraform [-version] [-help] <command> [args]' in captured.out
+    assert "runway" not in captured.out
+    assert "terraform [-version] [-help] <command> [args]" in captured.out
 
 
 def test_tfenv_run_version(cd_tmp_path, capfd):
@@ -89,10 +89,10 @@ def test_tfenv_run_version(cd_tmp_path, capfd):
     Parsing of bare command.
 
     """
-    version = '0.12.0'
-    (cd_tmp_path / '.terraform-version').write_text(six.u(version))
+    version = "0.12.0"
+    (cd_tmp_path / ".terraform-version").write_text(six.u(version))
     runner = CliRunner()
-    result = runner.invoke(cli, ['tfenv', 'run', '--version'])
+    result = runner.invoke(cli, ["tfenv", "run", "--version"])
     captured = capfd.readouterr()  # capfd required for subprocess
     assert result.exit_code == 0
-    assert 'Terraform v{}'.format(version) in captured.out
+    assert "Terraform v{}".format(version) in captured.out
